[Libreoffice-commits] core.git: comphelper/inc connectivity/source embeddedobj/source odk/examples svx/source xmloff/dtd

Julien Nabet serval2412 at yahoo.fr
Thu Feb 28 08:05:37 PST 2013


 comphelper/inc/comphelper/embeddedobjectcontainer.hxx                        |    2 +-
 connectivity/source/drivers/mozab/bootstrap/MNSProfileDirServiceProvider.cxx |    6 +++---
 embeddedobj/source/commonembedding/persistence.cxx                           |    6 +++---
 embeddedobj/source/general/dummyobject.cxx                                   |    2 +-
 embeddedobj/source/msole/olepersist.cxx                                      |    6 +++---
 odk/examples/java/EmbedDocument/EmbeddedObject/OwnEmbeddedObject.java        |    4 ++--
 svx/source/unodraw/unoshape.cxx                                              |    4 ++--
 xmloff/dtd/table.mod                                                         |    2 +-
 8 files changed, 16 insertions(+), 16 deletions(-)

New commits:
commit c13802e009035a22b9d38a045c7feb15b1c659a7
Author: Julien Nabet <serval2412 at yahoo.fr>
Date:   Sat Feb 23 15:06:20 2013 +0100

    Fix typo "persistant" -> "persistant"
    
    Change-Id: I639afec2508d189c10a180fd8f824e634afbd14a
    Reviewed-on: https://gerrit.libreoffice.org/2347
    Reviewed-by: Michael Stahl <mstahl at redhat.com>
    Tested-by: Michael Stahl <mstahl at redhat.com>

diff --git a/comphelper/inc/comphelper/embeddedobjectcontainer.hxx b/comphelper/inc/comphelper/embeddedobjectcontainer.hxx
index f9b7bd9..2312b2d 100644
--- a/comphelper/inc/comphelper/embeddedobjectcontainer.hxx
+++ b/comphelper/inc/comphelper/embeddedobjectcontainer.hxx
@@ -100,7 +100,7 @@ public:
                         CreateEmbeddedObject( const com::sun::star::uno::Sequence < sal_Int8 >&,
                         const com::sun::star::uno::Sequence < com::sun::star::beans::PropertyValue >&, ::rtl::OUString& );
 
-    // insert an embedded object into the container - objects persistant representation will be added to the storage
+    // insert an embedded object into the container - objects persistent representation will be added to the storage
     sal_Bool            InsertEmbeddedObject( const ::com::sun::star::uno::Reference < ::com::sun::star::embed::XEmbeddedObject >&, ::rtl::OUString& );
 
     // load an embedded object from a MediaDescriptor and insert it into the container
diff --git a/connectivity/source/drivers/mozab/bootstrap/MNSProfileDirServiceProvider.cxx b/connectivity/source/drivers/mozab/bootstrap/MNSProfileDirServiceProvider.cxx
index c00249d..b3e52c6 100644
--- a/connectivity/source/drivers/mozab/bootstrap/MNSProfileDirServiceProvider.cxx
+++ b/connectivity/source/drivers/mozab/bootstrap/MNSProfileDirServiceProvider.cxx
@@ -104,16 +104,16 @@ NS_IMPL_THREADSAFE_ISUPPORTS1(nsProfileDirServiceProvider,
 // nsProfileDirServiceProvider::nsIDirectoryServiceProvider
 
 NS_IMETHODIMP
-nsProfileDirServiceProvider::GetFile(const char *prop, PRBool *persistant, nsIFile **_retval)
+nsProfileDirServiceProvider::GetFile(const char *prop, PRBool *persistent, nsIFile **_retval)
 {
   NS_ENSURE_ARG(prop);
-  NS_ENSURE_ARG_POINTER(persistant);
+  NS_ENSURE_ARG_POINTER(persistent);
   NS_ENSURE_ARG_POINTER(_retval);
 
   if (!mProfileDir)
     return NS_ERROR_FAILURE;
 
-  *persistant = PR_TRUE;
+  *persistent = PR_TRUE;
   nsIFile* domainDir = mProfileDir;
 
 
diff --git a/embeddedobj/source/general/dummyobject.cxx b/embeddedobj/source/general/dummyobject.cxx
index 057fe8a..8c309d0 100644
--- a/embeddedobj/source/general/dummyobject.cxx
+++ b/embeddedobj/source/general/dummyobject.cxx
@@ -324,7 +324,7 @@ void SAL_CALL ODummyEmbeddedObject::setPersistentEntry(
       && ( m_nObjectState == -1 || nEntryConnectionMode != embed::EntryInitModes::NO_INIT ) )
     {
         throw embed::WrongStateException(
-                    ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "Can't change persistant representation of activated object!\n" )),
+                    ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "Can't change persistent representation of activated object!\n" )),
                     uno::Reference< uno::XInterface >( static_cast< ::cppu::OWeakObject* >(this) ) );
     }
 
diff --git a/odk/examples/java/EmbedDocument/EmbeddedObject/OwnEmbeddedObject.java b/odk/examples/java/EmbedDocument/EmbeddedObject/OwnEmbeddedObject.java
index 44ee37c..cdf3c29 100644
--- a/odk/examples/java/EmbedDocument/EmbeddedObject/OwnEmbeddedObject.java
+++ b/odk/examples/java/EmbedDocument/EmbeddedObject/OwnEmbeddedObject.java
@@ -381,10 +381,10 @@ public final class OwnEmbeddedObject extends WeakBase
           && ( m_nObjectState == -1 || nEntryConnectionMode != com.sun.star.embed.EntryInitModes.NO_INIT ) )
         {
             // if the object is not loaded
-            // it can not get persistant representation without initialization
+            // it can not get persistent representation without initialization
 
             // if the object is loaded
-            // it can switch persistant representation only without initialization
+            // it can switch persistent representation only without initialization
 
             throw new com.sun.star.embed.WrongStateException();
         }
diff --git a/svx/source/unodraw/unoshape.cxx b/svx/source/unodraw/unoshape.cxx
index 2219525..c453ea4 100644
--- a/svx/source/unodraw/unoshape.cxx
+++ b/svx/source/unodraw/unoshape.cxx
@@ -1737,7 +1737,7 @@ void SAL_CALL SvxShape::_setPropertyValue( const OUString& rPropertyName, const
                 {
                     if(bIsNotPersist)
                     {
-                        // Not-Persistant Attribute, hole diese extra
+                        // Not-Persistent Attribute, hole diese extra
                         mpObj->TakeNotPersistAttr(*pSet, sal_False);
                     }
                 }
@@ -1833,7 +1833,7 @@ uno::Any SvxShape::_getPropertyValue( const OUString& PropertyName )
             {
                 if(pMap->nWID >= SDRATTR_NOTPERSIST_FIRST && pMap->nWID <= SDRATTR_NOTPERSIST_LAST)
                 {
-                    // Not-Persistant Attribute, hole diese extra
+                    // Not-Persistent Attribute, hole diese extra
                     mpObj->TakeNotPersistAttr(aSet, sal_False);
                 }
             }
diff --git a/xmloff/dtd/table.mod b/xmloff/dtd/table.mod
index 1b58210..8e33b0c 100644
--- a/xmloff/dtd/table.mod
+++ b/xmloff/dtd/table.mod
@@ -365,7 +365,7 @@
 	table:is-selection %boolean; "false"
 	table:on-update-keep-styles %boolean; "false"
 	table:on-update-keep-size %boolean; "true"
-	table:has-persistant-data %boolean; "true"
+	table:has-persistent-data %boolean; "true"
 	table:orientation (row | column) "row"
 	table:contains-header %boolean; "true"
 	table:display-filter-buttons %boolean; "false"


More information about the Libreoffice-commits mailing list
diff --git a/embeddedobj/source/commonembedding/persistence.cxx b/embeddedobj/source/commonembedding/persistence.cxx
index 7899567..b7e61e4 100644
--- a/embeddedobj/source/commonembedding/persistence.cxx
+++ b/embeddedobj/source/commonembedding/persistence.cxx
@@ -937,13 +937,13 @@ void SAL_CALL OCommonEmbeddedObject::setPersistentEntry(
       && ( m_nObjectState == -1 || nEntryConnectionMode != embed::EntryInitModes::NO_INIT ) )
     {
         // if the object is not loaded
         // it can not get persistant representation without initialization
 
         // if the object is loaded
         // it can switch persistant representation only without initialization
 
         throw embed::WrongStateException(
-                    ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "Can't change persistant representation of activated object!\n" )),
+                    ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "Can't change persistent representation of activated object!\n" )),
                     uno::Reference< uno::XInterface >( static_cast< ::cppu::OWeakObject* >(this) ) );
     }
 
@@ -937,13 +937,13 @@ void SAL_CALL OCommonEmbeddedObject::setPersistentEntry(
     {
         // if the object is not loaded
-        // it can not get persistant representation without initialization
+        // it can not get persistent representation without initialization
 
         // if the object is loaded
@@ -937,13 +937,13 @@ void SAL_CALL OCommonEmbeddedObject::setPersistentEntry(
 
         // if the object is loaded
-        // it can switch persistant representation only without initialization
+        // it can switch persistent representation only without initialization
 
         throw embed::WrongStateException(
diff --git a/embeddedobj/source/msole/olepersist.cxx b/embeddedobj/source/msole/olepersist.cxx
index 18e01cd..e9daaca 100644
--- a/embeddedobj/source/msole/olepersist.cxx
+++ b/embeddedobj/source/msole/olepersist.cxx
@@ -1331,13 +1331,13 @@ void SAL_CALL OleEmbeddedObject::setPersistentEntry(
       && ( m_nObjectState == -1 || nEntryConnectionMode != embed::EntryInitModes::NO_INIT ) )
     {
         // if the object is not loaded
         // it can not get persistant representation without initialization
 
         // if the object is loaded
         // it can switch persistant representation only without initialization
 
         throw embed::WrongStateException(
-                    ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "Can't change persistant representation of activated object!\n" )),
+                    ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "Can't change persistent representation of activated object!\n" )),
                     uno::Reference< uno::XInterface >( static_cast< ::cppu::OWeakObject* >(this) ) );
     }
 
@@ -1331,13 +1331,13 @@ void SAL_CALL OleEmbeddedObject::setPersistentEntry(
     {
         // if the object is not loaded
-        // it can not get persistant representation without initialization
+        // it can not get persistent representation without initialization
 
         // if the object is loaded
@@ -1331,13 +1331,13 @@ void SAL_CALL OleEmbeddedObject::setPersistentEntry(
 
         // if the object is loaded
-        // it can switch persistant representation only without initialization
+        // it can switch persistent representation only without initialization
 
         throw embed::WrongStateException(